@@ -82,6 +82,7 @@ class GeneticAlgorithm:
                  deep_learning_type: str = 'batch',
                  deep_learning_output_size: int = None,
                  cloud: str = None,
+                 deploy_model: bool = True,
                  multi_threading: bool = False,
                  multi_processing: bool = False,
                  log: bool = False,
@@ -227,6 +228,9 @@ class GeneticAlgorithm:
                 -> google: Google Cloud Storage
                 -> aws: AWS Cloud
 
+        :param deploy_model: bool
+            Whether to deploy (save) evolved model or not
+
         :param multi_threading: bool
             Whether to run genetic algorithm using multiple threads (of one cpu core) or single thread
 
@@ -247,9 +251,9 @@ class GeneticAlgorithm:
         self.mode = mode
         self.model = None
         self.model_params: dict = copy.deepcopy(model_params)
-        self.deploy_model: bool = False
+        self.deploy_model: bool = deploy_model
         self.n_training: int = 0
-        self.cloud: str = None
+        self.cloud: str = cloud
         if self.cloud is None:
             self.bucket_name: str = None
         else:
